[lld] 3949a3e - [ELF][test] Add --emit-relocs --gc-sections test for relocation section for a non-SHF_ALLOC section

Fangrui Song via llvm-commits llvm-commits at lists.llvm.org
Sat Jan 30 00:51:43 PST 2021


Author: Fangrui Song
Date: 2021-01-30T00:51:36-08:00
New Revision: 3949a3ed49bbd95235c3c616bf4dbae4ecac48bc

URL: https://github.com/llvm/llvm-project/commit/3949a3ed49bbd95235c3c616bf4dbae4ecac48bc
DIFF: https://github.com/llvm/llvm-project/commit/3949a3ed49bbd95235c3c616bf4dbae4ecac48bc.diff

LOG: [ELF][test] Add --emit-relocs --gc-sections test for relocation section for a non-SHF_ALLOC section

This has been fixed by D89841.

Added: 
    

Modified: 
    lld/test/ELF/emit-relocs-gc.s

Removed: 
    


################################################################################
diff  --git a/lld/test/ELF/emit-relocs-gc.s b/lld/test/ELF/emit-relocs-gc.s
index 97ff8074013a..06a11947b022 100644
--- a/lld/test/ELF/emit-relocs-gc.s
+++ b/lld/test/ELF/emit-relocs-gc.s
@@ -1,22 +1,24 @@
 # REQUIRES: x86
 # RUN: llvm-mc -filetype=obj -triple=x86_64-unknown-linux %s -o %t.o
 
 ## Show that we emit .rela.bar and .rela.text when GC is disabled.
 # RUN: ld.lld --emit-relocs %t.o -o %t
 # RUN: llvm-objdump %t --section-headers | FileCheck %s --check-prefix=NOGC
 # NOGC: .rela.text
 # NOGC: .rela.bar
+# NOGC: .rela.debug_info
 
 ## GC collects .bar section and we exclude .rela.bar from output. We keep
-## .rela.text because we keep .text.
+## .rela.text because we keep .text. We keep .rela.debug_info because we keep
+## non-SHF_ALLOC .debug_info.
 # RUN: ld.lld --gc-sections --emit-relocs --print-gc-sections %t.o -o %t \
 # RUN:   | FileCheck --check-prefix=MSG %s
 # MSG: removing unused section {{.*}}.o:(.bar)
 # MSG: removing unused section {{.*}}.o:(.rela.bar)
 # RUN: llvm-objdump %t --section-headers | FileCheck %s --check-prefix=GC
 # GC-NOT:  rela.bar
 # GC:      rela.text
 # GC-NOT:  rela.bar
 
 .section .bar,"a"
 .quad .bar
@@ -28,3 +30,6 @@ relocs:
 .global _start
 _start:
  nop
+
+.section .debug_info,"", at progbits
+.quad .text


        
@@ -1,22 +1,24 @@
 # RUN: llvm-mc -filetype=obj -triple=x86_64-unknown-linux %s -o %t.o
 
-## Show that we emit .rela.bar and .rela.text when GC is disabled.
+## Show that we emit .rela.bar, .rela.text and .rela.debug_info when GC is disabled.
 # RUN: ld.lld --emit-relocs %t.o -o %t
 # RUN: llvm-objdump %t --section-headers | FileCheck %s --check-prefix=NOGC
@@ -1,22 +1,24 @@
 # MSG: removing unused section {{.*}}.o:(.bar)
 # MSG: removing unused section {{.*}}.o:(.rela.bar)
-# RUN: llvm-objdump %t --section-headers | FileCheck %s --check-prefix=GC
-# GC-NOT:  rela.bar
-# GC:      rela.text
-# GC-NOT:  rela.bar
+# RUN: llvm-objdump %t --section-headers | FileCheck %s --check-prefix=GC --implicit-check-not=.rela.
+# GC:      .rela.text
+# GC-NEXT: .debug_info
+# GC-NEXT: .rela.debug_info
 
 .section .bar,"a"


More information about the llvm-commits mailing list